Quick Start Guide — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Quick Start Guide

Contents:

- Quick Overview
  - 1. Querying CommonCrawl
  - 2. Downloading a file
  - 3. Choose parser
  - 4. Filtering out the web page
  - 5. Extract fields from the page
  - 6. File saving
- Quickstart
  - Extractor
  - download_article.py
  - Extracting (Transformations)
  - Extracting( BS4 version)
  - Filtering
  - config.json
  - Testing our extractor
  - Running the extractor
- Artemis Queue